@@ -1,6 +1,8 @@
-from pgjson import *
-from ltree import *
-from mutable import *
+from __future__ import absolute_import
+
+from sqlalchemy_postgresql_json.pgjson import *
+from sqlalchemy_postgresql_json.ltree import *
+from sqlalchemy_postgresql_json.mutable import *
 
 __all__ = ['monkey_patch_array',
            'monkey_patch_json',
@@ -8,6 +10,7 @@ __all__ = ['monkey_patch_array',
            'JSONMutableDict',
            'JSONMutableList',
            'JSON',
+           'register_json',
            'LTXTQUERY',
            'LTREE',
            'LQUERY',
